==> openGion_dev_5.1.6.0.zip: opengion/uap/webapps/gf/src/org/opengion/hayabusa/taglib/ErrorMessageTag.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.taglib;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.common.HybsSystemException;
import org.opengion.fukurou.util.ErrorMessage;
import org.opengion.fukurou.util.XHTMLTag;
import org.opengion.fukurou.util.Attributes;

import static org.opengion.fukurou.util.StringUtil.nval ;

import java.util.Locale ;
import java.io.ObjectOutputStream;
import java.io.ObjectInputStream;
import java.io.IOException;

/**
 * エラーメッセージを 表形式で表示するタグです。
 *
 * Query 関係の実行時にエラー/ワーニングが発生すると、HybsSystem.ERR_MSG_KEY をキーに
 * ErrorMessage オブジェクト をセッションに登録します。
 * この情報を元に、表題(TITLE)か、内容(BODY)を表示します。
 * 基本的には，表題表示時には，リンクを張り、共通エラー表示画面をオープン
 * 出来る様になっています。
 *
 * @og.formSample
 * ●形式：
 *     &lt;og:errorMessage command=&quot;{&#064;command}&quot; clear=&quot;{&#064;clear}&quot; /&gt;
 * ●body：なし
 *
 * ●使用例
 *    result.jsp 等のSQL登録実行後の戻り画面に、上記タグを配置すれば、
 *    エラーメッセージが存在すれば,リンクとなって現れ、無ければ,なにも
 *    現れません。
 *    リンクのとび先は自動的に設定されます。
 *    なお、clear=&quot;true&quot; または、command=&quot;NEW&quot; の場合に、エラーメッセージは、
 *    クリアされます。
 *
 *    [entry.jsp]
 *        &lt;% String forwardPage="result.jsp"; %&gt;
 *        &lt;jsp:forward page="&lt;%= response.encodeRedirectURL( forwardPage ) %&gt;" &gt;
 *            &lt;jsp:param name="command" value="REVIEW" /&gt;
 *            &lt;jsp:param name="clear"   value="false"  /&gt;
 *        &lt;/jsp:forward&gt;
 *
 *    [result.jsp]
 *        &lt;og:errorMessage command="{&#064;command}" clear="{&#064;clear}" /&gt;
 *
 * @og.group エラー処理
 *
 * @version  4.0
 * @author	 Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class ErrorMessageTag extends CommonTagSupport {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.0.0 (2005/08/31)" ;

	private static final long serialVersionUID = 4000 ;	// 4.0.0 (2005/01/31)

	/** command 引数に渡す事の出来る コマンド  新規 {@value} */
	public static final String CMD_NEW	 = "NEW" ;
	/** command 引数に渡す事の出来る コマンド  再検索 {@value} */
	public static final String CMD_RENEW = "RENEW" ;
	/** command 引数に渡す事の出来る コマンド  取消 {@value} */
	public static final String CMD_RESET = "RESET" ;
	/** command 引数に渡す事の出来る コマンド  再表示 {@value} */
	public static final String CMD_REVIEW	= "REVIEW" ;
	/** command 引数に渡す事の出来る コマンド リスト  */
// 	private static final String[] COMMAND_LIST = new String[] { CMD_NEW , CMD_RENEW , CMD_RESET , CMD_REVIEW };
	private static final String errMsgId	= HybsSystem.ERR_MSG_KEY;
	private final String errMsgFile	= HybsSystem.sys( "ERR_MSG_FILENAME" );
	private final int	maxRowCount = HybsSystem.sysInt( "DB_MAX_ROW_COUNT" ) ;

	private transient ErrorMessage	errMessage	= null;
	private String			command		= null;
	private boolean 		msgClear	= false;
	private String			viewType	= "TITLE";		// TITLE/BODY

	// 2.0.1.0 (2002/10/10) デフォルト表示しないから、MSG0059=登録しました。に変更します。
	private String		displayMsg	 = "MSG0059";	// 初期値は『登録しました。』
	private String		warningMsg	 = "ERR0020";	// データ登録時にワーニングが発生しました。

	/**
	 * Taglibの開始タグが見つかったときに処理する doStartTag() を オーバーライドします。
	 *
	 * @og.rev 3.5.4.0 (2003/11/25) エラーオブジェクトのクリアに、RENEW or null も追加します。
	 *
	 * @return	int
	 */
	@Override
	public int doStartTag() {
		// クリアが指示されるか、コマンドが NEW or RESET or RENEW or null の場合は、エラーをクリアする。
		if( msgClear || CMD_NEW.equals( command ) || CMD_RESET.equals( command ) ) {
		// 3.5.4.9 (2004/02/25) RENEW の時は、エラーをクリアしない。
			removeSessionAttribute( errMsgId );
			msgClear = true;
		}
		else {
			errMessage = (ErrorMessage)getSessionAttribute( errMsgId );
			if( errMessage == null ) { msgClear = true; }
		}

		return(SKIP_BODY);		// Body を評価しない
	}

	/**
	 * Taglibの終了タグが見つかったときに処理する doEndTag() を オーバーライドします。
	 *
	 * @og.rev 2.1.0.3 (2002/11/08) command = NEW のときも、『登録しました。』メッセージが表示されるバグを修正
	 * @og.rev 3.1.1.2 (2003/04/04) Tomcat4.1 対応。release2() を doEndTag()で呼ぶ。
	 * @og.rev 3.5.5.2 (2004/04/02) TaglibUtil.makeHTMLErrorTable メソッドを利用
	 * @og.rev 4.0.0.0 (2007/10/18) メッセージリソース統合( getResource().getMessage > getResource().getLabel )
	 * @og.rev 4.1.3.0 (2008/09/04) メッセージをspanで囲う(画面遷移なしモード対応)
	 *
	 * @return	int
	 */
	@Override
	public int doEndTag() {
		debugPrint();		// 4.0.0 (2005/02/28)

		String msg = null;
		if( errMessage == null ) {
			if( CMD_REVIEW.equals( command ) || CMD_RENEW.equals( command ) ) {
//				msg = getResource().getMessage( displayMsg ) + HybsSystem.BR;
				msg = getResource().getLabel( displayMsg ) + HybsSystem.BR;
			}
		}
		else {
			if( "TITLE".equalsIgnoreCase( viewType ) ) {
				msg = makeTitle();
			}
			else if( "BODY".equalsIgnoreCase( viewType ) ) {
				msg = TaglibUtil.makeHTMLErrorTable( errMessage,getResource() );	// 3.5.5.2 (2004/04/02)
			}
			else {
				String errMsg = "viewType属性に TITLE/BODY 以外の項目が指定されています。"
							+ "[" + viewType + "]" ;
				throw new HybsSystemException( errMsg );
			}
		}

		jspPrint( "<span class=\"errmsg\">" ); // 4.1.3.0 (2008/09/04)
		if( msg != null ) { jspPrint( msg ); }
		jspPrint( "</span>" );

		return(EVAL_PAGE);
	}

	/**
	 * タグリブオブジェクトをリリースします。
	 * キャッシュされて再利用されるので、フィールドの初期設定を行います。
	 *
	 * @og.rev 2.0.0.4 (2002/09/27) カスタムタグの release() メソッドを、追加
	 * @og.rev 2.0.1.0 (2002/10/10) デフォルト表示しないから、MSG0059=登録しました。に変更します。
	 * @og.rev 3.1.1.2 (2003/04/04) Tomcat4.1 対応。release2() を doEndTag()で呼ぶ。
	 *
	 */
	@Override
	protected void release2() {
		super.release2();
		command		= null;
		errMessage	= null;
		msgClear	= false;
		viewType	= "TITLE";		// TITLE/BODY
		displayMsg	= "MSG0059";	// 初期値は『登録しました。』
		warningMsg	= "ERR0020";	// データ登録時にワーニングが発生しました。
	}

	/**
	 * エラーメッセージをタグ情報の文字列に変換して返します。
	 *
	 * ここでは、正常なメッセージも異常なメッセージも作成します。
	 *
	 * @og.rev 3.6.0.1 (2004/09/29) ワーニング、エラー時のスタイルシートを適用
	 * @og.rev 3.6.0.7 (2004/11/06) target 属性を _new から _blank に変更
	 * @og.rev 4.0.0.0 (2007/10/18) メッセージリソース統合( getResource().getMessage > getResource().getLabel )
	 *
	 * @return	int
	 */
	private String makeTitle() {
		String href = getContextPath() + "/" + errMsgFile ;

		Attributes attri = new Attributes();
		attri.set( "href"	, href	 );
		attri.set( "target" , "_blank" );	// 3.6.0.7 (2004/11/06)

		final String title ;
		if( warningMsg != null ) {
			title = "<span class=\"msg_warning\">"
//					 + getResource().getMessage( warningMsg )
					 + getResource().getLabel( warningMsg )
					 + "</span>";
		}
		else {
			title = "<span class=\"msg_error\">"
					+ errMessage.getTitle()
					+ "</span>";
		}

		attri.set( "body" , title );

		String key = "pageSize";
		String val = String.valueOf( maxRowCount );
		String urlEnc = XHTMLTag.urlEncode( key,val );

		return XHTMLTag.link( attri,urlEnc ) ;
	}

	/**
	 * 【TAG】コマンド(NEW,RENEW,RESET,REVIEW)をセットします。
	 *
	 * @og.tag
	 * コマンドは,HTMLから（get/post)指定されますので,CMD_xxx で設定される
	 * フィールド定数値のいづれかを、指定できます。
	 *
	 * @param	cmd コマンド（public static final 宣言されている文字列)
	 * @see		<a href="{@docRoot}/constant-values.html#org.opengion.hayabusa.taglib.ErrorMessageTag.CMD_NEW">コマンド定数</a>
	 */
	public void setCommand( final String cmd ) {
		String cmd2 = getRequestParameter( cmd );
		if( cmd2 != null && cmd2.length() > 0 ) { command = cmd2.toUpperCase(Locale.JAPAN); }
	}

	/**
	 * 【TAG】メッセージを初期化するかどうか(true/false)を指定します(初期値:false)。
	 *
	 * @og.tag
	 * メッセージは、一般には，エラーメッセージかワーニングです。
	 * 最終処理でメッセージが無ければ，標準でクリアします。
	 * また、command が NEW の場合も、メッセージは自動でクリアされます。
	 * 初期値は、クリアしない (true 以外)です。
	 *
	 * @param	flag クリアする ("true")／しない (true 以外)
	 */
	public void setClear( final String flag ) {
		msgClear = nval( getRequestParameter( flag ),msgClear );
	}

	/**
	 * 【TAG】表示形式『表題(TITLE)か、内容(BODY)』を指定します(初期値:TITLE)。
	 *
	 * @og.tag
	 * 一般には，表題(TITLE) を表示しておきます。
	 * 表題表示時には，リンクを張り、共通エラー表示画面をオープン
	 * 出来る様になっています。
	 *
	 * @param	flag 表示形式 表題(TITLE)か、内容(BODY)
	 */
	public void setViewType( final String flag ) {
		viewType = nval( getRequestParameter( flag ),viewType );
	}

	/**
	 * 【TAG】plsqlUpdate の結果を画面上に表示するメッセージIDを指定します(初期値:MSG0059『登録しました』)。
	 *
	 * @og.tag
	 * 指定したメッセージをリソースから取得して表示します。
	 * 表示させたくない場合は, displayMsg = "MSG0065" をセットしてください。
	 * 初期値は、MSG0059『登録しました。』を表示します。
	 *
	 * @og.rev 2.0.1.0 (2002/10/10) デフォルト表示しないから、MSG0059=登録しました。に変更します。
	 * @og.rev 3.2.0.0 (2003/05/22) 引数に何もセットされないときに、デフォルトの文字を表示するように変更。
	 *
	 * @param	id ディスプレイに表示させるメッセージ ID
	 */
	public void setDisplayMsg( final String id ) {
		displayMsg = nval( getRequestParameter( id ),displayMsg );
	//	String ids = getRequestParameter( id );
	//	if( ids != null ) { displayMsg = ids; }
	}

	/**
	 * 【TAG】登録処理実行後のワーニング結果を画面上に表示するメッセージIDを指定します(初期値:ERR0020)。
	 *
	 * @og.tag
	 * 指定したメッセージをリソースから取得して表示します。
	 * 表示させたくない場合は, warningMsg = "" をセットしてください。
	 * 初期値は、ERR0020『データ登録時にワーニングが発生しました。』を表示します。
	 *
	 * @og.rev 2.0.1.0 (2002/10/10) デフォルト表示しないから、ERR0020=データ登録時にワーニングが発生しました。に変更します。
	 *
	 * @param	id ディスプレイに表示させるメッセージ ID
	 */
	public void setWarningMsg( final String id ) {
//		warningMsg = nval( getRequestParameter( id ),warningMsg );
		String ids = getRequestParameter( id );
		if( ids != null ) { warningMsg = ids; }
	}

	/**
	 * シリアライズ用のカスタムシリアライズ書き込みメソッド
	 *
	 * @og.rev 4.0.0 (2006/09/31) 新規追加
	 * @serialData
	 *
	 * @param strm ObjectOutputStream
	 */
	private void writeObject( final ObjectOutputStream strm ) throws IOException {
		strm.defaultWriteObject();
	}

	/**
	 * シリアライズ用のカスタムシリアライズ読み込みメソッド
	 *
	 * ここでは、transient 宣言された内部変数の内、初期化が必要なフィールドのみ設定します。
	 *
	 * @og.rev 4.0.0 (2006/09/31) 新規追加
	 * @serialData
	 *
	 * @param strm ObjectInputStream
	 * @see #release2()
	 */
	private void readObject( final ObjectInputStream strm ) throws IOException , ClassNotFoundException {
		strm.defaultReadObject();
	}

	/**
	 * デバッグ時の文字列を返します。
	 *
	 * @return	このオブジェクトのデバッグ表現文字列
	 */
	public String toString() {
		return org.opengion.fukurou.util.ToString.title( this.getClass().getName() )
				.println( "VERSION"		,VERSION	)
				.println( "errMsgId"	,errMsgId	)
				.println( "errMsgFile"	,errMsgFile	)
				.println( "maxRowCount" ,maxRowCount)
				.println( "command"		,command	)
				.println( "msgClear"	,msgClear	)
				.println( "viewType"	,viewType	)
				.println( "displayMsg"	,displayMsg	)
				.println( "warningMsg"	,warningMsg	)
				.println( "Other..."	,getAttributes().getAttribute() )
				.fixForm().toString() ;
	}
}

==> openGion_dev_5.1.9.0.zip: opengion/uap/webapps/gf/src/org/opengion/hayabusa/taglib/ErrorMessageTag.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.taglib;

import org.opengion.hayabusa.common.HybsSystem;
import org.opengion.hayabusa.common.HybsSystemException;
import org.opengion.fukurou.util.ErrorMessage;
import org.opengion.fukurou.util.XHTMLTag;
import org.opengion.fukurou.util.Attributes;

import static org.opengion.fukurou.util.StringUtil.nval ;

import java.util.Locale ;
import java.io.ObjectOutputStream;
import java.io.ObjectInputStream;
import java.io.IOException;

/**
 * エラーメッセージを 表形式で表示するタグです。
 *
 * Query 関係の実行時にエラー/ワーニングが発生すると、HybsSystem.ERR_MSG_KEY をキーに
 * ErrorMessage オブジェクト をセッションに登録します。
 * この情報を元に、表題(TITLE)か、内容(BODY)を表示します。
 * 基本的には，表題表示時には，リンクを張り、共通エラー表示画面をオープン
 * 出来る様になっています。
 *
 * @og.formSample
 * ●形式：
 *     &lt;og:errorMessage command=&quot;{&#064;command}&quot; clear=&quot;{&#064;clear}&quot; /&gt;
 * ●body：なし
 *
 * ●使用例
 *    result.jsp 等のSQL登録実行後の戻り画面に、上記タグを配置すれば、
 *    エラーメッセージが存在すれば,リンクとなって現れ、無ければ,なにも
 *    現れません。
 *    リンクのとび先は自動的に設定されます。
 *    なお、clear=&quot;true&quot; または、command=&quot;NEW&quot; の場合に、エラーメッセージは、
 *    クリアされます。
 *
 *    [entry.jsp]
 *        &lt;% String forwardPage="result.jsp"; %&gt;
 *        &lt;jsp:forward page="&lt;%= response.encodeRedirectURL( forwardPage ) %&gt;" &gt;
 *            &lt;jsp:param name="command" value="REVIEW" /&gt;
 *            &lt;jsp:param name="clear"   value="false"  /&gt;
 *        &lt;/jsp:forward&gt;
 *
 *    [result.jsp]
 *        &lt;og:errorMessage command="{&#064;command}" clear="{&#064;clear}" /&gt;
 *
 * @og.group エラー処理
 *
 * @version  4.0
 * @author	 Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class ErrorMessageTag extends CommonTagSupport {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.0.0 (2005/08/31)" ;

	private static final long serialVersionUID = 4000 ;	// 4.0.0 (2005/01/31)

	/** command 引数に渡す事の出来る コマンド  新規 {@value} */
	public static final String CMD_NEW	 = "NEW" ;
	/** command 引数に渡す事の出来る コマンド  再検索 {@value} */
	public static final String CMD_RENEW = "RENEW" ;
	/** command 引数に渡す事の出来る コマンド  取消 {@value} */
	public static final String CMD_RESET = "RESET" ;
	/** command 引数に渡す事の出来る コマンド  再表示 {@value} */
	public static final String CMD_REVIEW	= "REVIEW" ;
	/** command 引数に渡す事の出来る コマンド リスト  */
// 	private static final String[] COMMAND_LIST = new String[] { CMD_NEW , CMD_RENEW , CMD_RESET , CMD_REVIEW };
	private static final String errMsgId	= HybsSystem.ERR_MSG_KEY;
	private final String errMsgFile	= HybsSystem.sys( "ERR_MSG_FILENAME" );
	private final int	maxRowCount = HybsSystem.sysInt( "DB_MAX_ROW_COUNT" ) ;

	private transient ErrorMessage	errMessage	= null;
	private String			command		= null;
	private boolean 		msgClear	= false;
	private String			viewType	= "TITLE";		// TITLE/BODY

	// 2.0.1.0 (2002/10/10) デフォルト表示しないから、MSG0059=登録しました。に変更します。
	private String		displayMsg	 = "MSG0059";	// 初期値は『登録しました。』
	private String		warningMsg	 = "ERR0020";	// データ登録時にワーニングが発生しました。

	/**
	 * Taglibの開始タグが見つかったときに処理する doStartTag() を オーバーライドします。
	 *
	 * @og.rev 3.5.4.0 (2003/11/25) エラーオブジェクトのクリアに、RENEW or null も追加します。
	 *
	 * @return	int
	 */
	@Override
	public int doStartTag() {
		// クリアが指示されるか、コマンドが NEW or RESET or RENEW or null の場合は、エラーをクリアする。
		if( msgClear || CMD_NEW.equals( command ) || CMD_RESET.equals( command ) ) {
		// 3.5.4.9 (2004/02/25) RENEW の時は、エラーをクリアしない。
			removeSessionAttribute( errMsgId );
			msgClear = true;
		}
		else {
			errMessage = (ErrorMessage)getSessionAttribute( errMsgId );
			if( errMessage == null ) { msgClear = true; }
		}

		return(SKIP_BODY);		// Body を評価しない
	}

	/**
	 * Taglibの終了タグが見つかったときに処理する doEndTag() を オーバーライドします。
	 *
	 * @og.rev 2.1.0.3 (2002/11/08) command = NEW のときも、『登録しました。』メッセージが表示されるバグを修正
	 * @og.rev 3.1.1.2 (2003/04/04) Tomcat4.1 対応。release2() を doEndTag()で呼ぶ。
	 * @og.rev 3.5.5.2 (2004/04/02) TaglibUtil.makeHTMLErrorTable メソッドを利用
	 * @og.rev 4.0.0.0 (2007/10/18) メッセージリソース統合( getResource().getMessage > getResource().getLabel )
	 * @og.rev 4.1.3.0 (2008/09/04) メッセージをspanで囲う(画面遷移なしモード対応)
	 *
	 * @return	int
	 */
	@Override
	public int doEndTag() {
		debugPrint();		// 4.0.0 (2005/02/28)

		String msg = null;
		if( errMessage == null ) {
			if( CMD_REVIEW.equals( command ) || CMD_RENEW.equals( command ) ) {
//				msg = getResource().getMessage( displayMsg ) + HybsSystem.BR;
				msg = getResource().getLabel( displayMsg ) + HybsSystem.BR;
			}
		}
		else {
			if( "TITLE".equalsIgnoreCase( viewType ) ) {
				msg = makeTitle();
			}
			else if( "BODY".equalsIgnoreCase( viewType ) ) {
				msg = TaglibUtil.makeHTMLErrorTable( errMessage,getResource() );	// 3.5.5.2 (2004/04/02)
			}
			else {
				String errMsg = "viewType属性に TITLE/BODY 以外の項目が指定されています。"
							+ "[" + viewType + "]" ;
				throw new HybsSystemException( errMsg );
			}
		}

		jspPrint( "<span class=\"errmsg\">" ); // 4.1.3.0 (2008/09/04)
		if( msg != null ) { jspPrint( msg ); }
		jspPrint( "</span>" );

		return(EVAL_PAGE);
	}

	/**
	 * タグリブオブジェクトをリリースします。
	 * キャッシュされて再利用されるので、フィールドの初期設定を行います。
	 *
	 * @og.rev 2.0.0.4 (2002/09/27) カスタムタグの release() メソッドを、追加
	 * @og.rev 2.0.1.0 (2002/10/10) デフォルト表示しないから、MSG0059=登録しました。に変更します。
	 * @og.rev 3.1.1.2 (2003/04/04) Tomcat4.1 対応。release2() を doEndTag()で呼ぶ。
	 *
	 */
	@Override
	protected void release2() {
		super.release2();
		command		= null;
		errMessage	= null;
		msgClear	= false;
		viewType	= "TITLE";		// TITLE/BODY
		displayMsg	= "MSG0059";	// 初期値は『登録しました。』
		warningMsg	= "ERR0020";	// データ登録時にワーニングが発生しました。
	}

	/**
	 * エラーメッセージをタグ情報の文字列に変換して返します。
	 *
	 * ここでは、正常なメッセージも異常なメッセージも作成します。
	 *
	 * @og.rev 3.6.0.1 (2004/09/29) ワーニング、エラー時のスタイルシートを適用
	 * @og.rev 3.6.0.7 (2004/11/06) target 属性を _new から _blank に変更
	 * @og.rev 4.0.0.0 (2007/10/18) メッセージリソース統合( getResource().getMessage > getResource().getLabel )
	 * @og.rev 5.1.7.0 (2010/06/01) エラー・ワーニングメッセージの後に改行を入れる(displayMsgと仕様を合わせる)
	 *
	 * @return	int
	 */
	private String makeTitle() {
		String href = getContextPath() + "/" + errMsgFile ;

		Attributes attri = new Attributes();
		attri.set( "href"	, href	 );
		attri.set( "target" , "_blank" );	// 3.6.0.7 (2004/11/06)

		final String title ;
		if( warningMsg != null ) {
			title = "<span class=\"msg_warning\">"
//					 + getResource().getMessage( warningMsg )
					 + getResource().getLabel( warningMsg )
					 // 5.1.7.0 (2010/06/01) ワーニングメッセージの後に改行を入れる
					 + "</span>" + HybsSystem.BR;
		}
		else {
			title = "<span class=\"msg_error\">"
					+ errMessage.getTitle()
					 // 5.1.7.0 (2010/06/01) エラーメッセージの後に改行を入れる
					 + "</span>" + HybsSystem.BR;
		}

		attri.set( "body" , title );

		String key = "pageSize";
		String val = String.valueOf( maxRowCount );
		String urlEnc = XHTMLTag.urlEncode( key,val );

		return XHTMLTag.link( attri,urlEnc ) ;
	}

	/**
	 * 【TAG】コマンド(NEW,RENEW,RESET,REVIEW)をセットします。
	 *
	 * @og.tag
	 * コマンドは,HTMLから（get/post)指定されますので,CMD_xxx で設定される
	 * フィールド定数値のいづれかを、指定できます。
	 *
	 * @param	cmd コマンド（public static final 宣言されている文字列)
	 * @see		<a href="{@docRoot}/constant-values.html#org.opengion.hayabusa.taglib.ErrorMessageTag.CMD_NEW">コマンド定数</a>
	 */
	public void setCommand( final String cmd ) {
		String cmd2 = getRequestParameter( cmd );
		if( cmd2 != null && cmd2.length() > 0 ) { command = cmd2.toUpperCase(Locale.JAPAN); }
	}

	/**
	 * 【TAG】メッセージを初期化するかどうか(true/false)を指定します(初期値:false)。
	 *
	 * @og.tag
	 * メッセージは、一般には，エラーメッセージかワーニングです。
	 * 最終処理でメッセージが無ければ，標準でクリアします。
	 * また、command が NEW の場合も、メッセージは自動でクリアされます。
	 * 初期値は、クリアしない (true 以外)です。
	 *
	 * @param	flag クリアする ("true")／しない (true 以外)
	 */
	public void setClear( final String flag ) {
		msgClear = nval( getRequestParameter( flag ),msgClear );
	}

	/**
	 * 【TAG】表示形式『表題(TITLE)か、内容(BODY)』を指定します(初期値:TITLE)。
	 *
	 * @og.tag
	 * 一般には，表題(TITLE) を表示しておきます。
	 * 表題表示時には，リンクを張り、共通エラー表示画面をオープン
	 * 出来る様になっています。
	 *
	 * @param	flag 表示形式 表題(TITLE)か、内容(BODY)
	 */
	public void setViewType( final String flag ) {
		viewType = nval( getRequestParameter( flag ),viewType );
	}

	/**
	 * 【TAG】plsqlUpdate の結果を画面上に表示するメッセージIDを指定します(初期値:MSG0059『登録しました』)。
	 *
	 * @og.tag
	 * 指定したメッセージをリソースから取得して表示します。
	 * 表示させたくない場合は, displayMsg = "MSG0065" をセットしてください。
	 * 初期値は、MSG0059『登録しました。』を表示します。
	 *
	 * @og.rev 2.0.1.0 (2002/10/10) デフォルト表示しないから、MSG0059=登録しました。に変更します。
	 * @og.rev 3.2.0.0 (2003/05/22) 引数に何もセットされないときに、デフォルトの文字を表示するように変更。
	 *
	 * @param	id ディスプレイに表示させるメッセージ ID
	 */
	public void setDisplayMsg( final String id ) {
		displayMsg = nval( getRequestParameter( id ),displayMsg );
	//	String ids = getRequestParameter( id );
	//	if( ids != null ) { displayMsg = ids; }
	}

	/**
	 * 【TAG】登録処理実行後のワーニング結果を画面上に表示するメッセージIDを指定します(初期値:ERR0020)。
	 *
	 * @og.tag
	 * 指定したメッセージをリソースから取得して表示します。
	 * 表示させたくない場合は, warningMsg = "" をセットしてください。
	 * 初期値は、ERR0020『データ登録時にワーニングが発生しました。』を表示します。
	 *
	 * @og.rev 2.0.1.0 (2002/10/10) デフォルト表示しないから、ERR0020=データ登録時にワーニングが発生しました。に変更します。
	 *
	 * @param	id ディスプレイに表示させるメッセージ ID
	 */
	public void setWarningMsg( final String id ) {
//		warningMsg = nval( getRequestParameter( id ),warningMsg );
		String ids = getRequestParameter( id );
		if( ids != null ) { warningMsg = ids; }
	}

	/**
	 * シリアライズ用のカスタムシリアライズ書き込みメソッド
	 *
	 * @og.rev 4.0.0 (2006/09/31) 新規追加
	 * @serialData
	 *
	 * @param strm ObjectOutputStream
	 */
	private void writeObject( final ObjectOutputStream strm ) throws IOException {
		strm.defaultWriteObject();
	}

	/**
	 * シリアライズ用のカスタムシリアライズ読み込みメソッド
	 *
	 * ここでは、transient 宣言された内部変数の内、初期化が必要なフィールドのみ設定します。
	 *
	 * @og.rev 4.0.0 (2006/09/31) 新規追加
	 * @serialData
	 *
	 * @param strm ObjectInputStream
	 * @see #release2()
	 */
	private void readObject( final ObjectInputStream strm ) throws IOException , ClassNotFoundException {
		strm.defaultReadObject();
	}

	/**
	 * デバッグ時の文字列を返します。
	 *
	 * @return	このオブジェクトのデバッグ表現文字列
	 */
	public String toString() {
		return org.opengion.fukurou.util.ToString.title( this.getClass().getName() )
				.println( "VERSION"		,VERSION	)
				.println( "errMsgId"	,errMsgId	)
				.println( "errMsgFile"	,errMsgFile	)
				.println( "maxRowCount" ,maxRowCount)
				.println( "command"		,command	)
				.println( "msgClear"	,msgClear	)
				.println( "viewType"	,viewType	)
				.println( "displayMsg"	,displayMsg	)
				.println( "warningMsg"	,warningMsg	)
				.println( "Other..."	,getAttributes().getAttribute() )
				.fixForm().toString() ;
	}
}
